==> jincore-src-1.106.2.zip: jincore-src-1.106.2/test/jp/sourceforge/jindolf/corelib/DestinyTest.java <==
/*
 */

package jp.sourceforge.jindolf.corelib;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 */
public class DestinyTest {

    public DestinyTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception{
    }

    @AfterClass
    public static void tearDownClass() throws Exception{
    }

    @Before
    public void setUp() {
    }

    @After
    public void tearDown() {
    }

    /**
     * Test of values method, of class Destiny.
     */
    @Test
    public void testValues(){
        System.out.println("values");
        Destiny[] values = Destiny.values();
        assertEquals(5, values.length);
        assertEquals(Destiny.ALIVE,       values[0]);
        assertEquals(Destiny.SUDDENDEATH, values[1]);
        assertEquals(Destiny.EXECUTED,    values[2]);
        assertEquals(Destiny.EATEN,       values[3]);
        assertEquals(Destiny.DISSOLVE,    values[4]);
        return;
    }

    /**
     * Test of valueOf method, of class Destiny.
     */
    @Test
    public void testValueOf(){
        System.out.println("valueOf");
        assertEquals(Destiny.ALIVE,       Destiny.valueOf("ALIVE"));
        assertEquals(Destiny.SUDDENDEATH, Destiny.valueOf("SUDDENDEATH"));
        assertEquals(Destiny.EXECUTED,    Destiny.valueOf("EXECUTED"));
        assertEquals(Destiny.EATEN,       Destiny.valueOf("EATEN"));
        assertEquals(Destiny.DISSOLVE,    Destiny.valueOf("DISSOLVE"));
        return;
    }

    /**
     * Test of getMessage method, of class Destiny.
     */
    @Test
    public void testGetMessage(){
        System.out.println("getMessage");
        assertEquals("生存",     Destiny.ALIVE.getMessage());
        assertEquals("突然死",   Destiny.SUDDENDEATH.getMessage());
        assertEquals("処刑死",   Destiny.EXECUTED.getMessage());
        assertEquals("襲撃死",   Destiny.EATEN.getMessage());
        assertEquals("ハム溶け", Destiny.DISSOLVE.getMessage());
        return;
    }

}

==> jincore-src-1.202.2.zip: jincore-src-1.202.2/test/jp/sourceforge/jindolf/corelib/DestinyTest.java <==
/*
 * Copyright(c) 2009 olyutorskii
 * $Id: DestinyTest.java 683 2009-08-19 05:10:06Z olyutorskii $
 */

package jp.sourceforge.jindolf.corelib;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 */
public class DestinyTest {

    public DestinyTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception{
    }

    @AfterClass
    public static void tearDownClass() throws Exception{
    }

    @Before
    public void setUp() {
    }

    @After
    public void tearDown() {
    }

    /**
     * Test of values method, of class Destiny.
     */
    @Test
    public void testValues(){
        System.out.println("values");
        Destiny[] values = Destiny.values();
        assertEquals(5, values.length);
        return;
    }

    /**
     * Test of valueOf method, of class Destiny.
     */
    @Test
    public void testValueOf(){
        // NOTHING
        return;
    }

    /**
     * Test of getMessage method, of class Destiny.
     */
    @Test
    public void testGetMessage(){
        System.out.println("getMessage");
        assertEquals("生存",     Destiny.ALIVE.getMessage());
        assertEquals("突然死",   Destiny.SUDDENDEATH.getMessage());
        assertEquals("処刑死",   Destiny.EXECUTED.getMessage());
        assertEquals("襲撃死",   Destiny.EATEN.getMessage());
        assertEquals("ハム溶け", Destiny.DISSOLVE.getMessage());
        return;
    }

}
